pub enum SimpleInstruction {
Show 39 variants Nop, Ret, BrTrue, BrFalse, Branch, Pop, LdU8, LdU64, LdU128, LdTrue, LdFalse, FreezeRef, MutBorrowLoc, ImmBorrowLoc, ImmBorrowField, MutBorrowField, ImmBorrowFieldGeneric, MutBorrowFieldGeneric, CastU8, CastU64, CastU128, Add, Sub, Mul, Mod, Div, BitOr, BitAnd, Xor, Shl, Shr, Or, And, Not, Lt, Gt, Le, Ge, Abort,
}
Enum of instructions that do not need extra information for gas metering.

Variants

Nop

Ret

BrTrue

BrFalse

Branch

Pop

LdU8

LdU64

LdU128

LdTrue

LdFalse

FreezeRef

MutBorrowLoc

ImmBorrowLoc

ImmBorrowField

MutBorrowField

ImmBorrowFieldGeneric

MutBorrowFieldGeneric

CastU8

CastU64

CastU128

Add

Sub

Mul

Mod

Div

BitOr

BitAnd

Xor

Shl

Shr

Or

And

Not

Lt

Gt

Le

Ge

Abort