pub trait TypeView {
    fn to_type_tag(&self) -> TypeTag;
}
Trait that provides an abstract view into a Move type.

This is used to expose certain info to clients (e.g. the gas meter), usually in a lazily evaluated fashion.

Required Methods

Returns the TypeTag (fully qualified name) of the type.

Implementations on Foreign Types

Implementors