Trait move_vm_types::views::TypeView
source · [−]pub trait TypeView {
fn to_type_tag(&self) -> TypeTag;
}Expand description
Trait that provides an abstract view into a Move type.
This is used to expose certain info to clients (e.g. the gas meter), usually in a lazily evaluated fashion.
Required Methods
fn to_type_tag(&self) -> TypeTag
fn to_type_tag(&self) -> TypeTag
Returns the TypeTag (fully qualified name) of the type.