pub trait ValueView {
    fn legacy_abstract_memory_size(&self) -> AbstractMemorySize;
}
Trait that provides an abstract view into a Move Value.

This is used to expose certain info to clients (e.g. the gas meter), usually in a lazily evaluated fashion.

Required Methods

Returns the abstract memory size of the value.

The concept of abstract memory size is not well-defined and is only kept for backward compatibility. New applications should avoid using this.

Implementations on Foreign Types

Implementors