Trait move_vm_types::views::ValueView
source · [−]pub trait ValueView {
fn legacy_abstract_memory_size(&self) -> AbstractMemorySize;
}Expand description
Trait that provides an abstract view into a Move Value.
This is used to expose certain info to clients (e.g. the gas meter), usually in a lazily evaluated fashion.
Required Methods
fn legacy_abstract_memory_size(&self) -> AbstractMemorySize
fn legacy_abstract_memory_size(&self) -> AbstractMemorySize
Returns the abstract memory size of the value.
The concept of abstract memory size is not well-defined and is only kept for backward compatibility. New applications should avoid using this.